# This file is generated by objective.metadata
#
# Last update: Mon Mar 16 20:56:08 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
misc.update(
    {
        "VTInt32Point": objc.createStructType(
            "VTInt32Point", b"{VTInt32Point=ii}", ["x", "y"]
        ),
        "VTInt32Size": objc.createStructType(
            "VTInt32Size", b"{VTInt32Size=ii}", ["width", "height"]
        ),
    }
)
constants = """$kVTAlphaChannelMode_PremultipliedAlpha@^{__CFString=}$kVTAlphaChannelMode_StraightAlpha@^{__CFString=}$kVTCompressionPropertyKey_AllowFrameReordering@^{__CFString=}$kVTCompressionPropertyKey_AllowOpenGOP@^{__CFString=}$kVTCompressionPropertyKey_AllowTemporalCompression@^{__CFString=}$kVTCompressionPropertyKey_AlphaChannelMode@^{__CFString=}$kVTCompressionPropertyKey_AspectRatio16x9@^{__CFString=}$kVTCompressionPropertyKey_AverageBitRate@^{__CFString=}$kVTCompressionPropertyKey_BaseLayerFrameRate@^{__CFString=}$kVTCompressionPropertyKey_CleanAperture@^{__CFString=}$kVTCompressionPropertyKey_ColorPrimaries@^{__CFString=}$kVTCompressionPropertyKey_ContentLightLevelInfo@^{__CFString=}$kVTCompressionPropertyKey_DataRateLimits@^{__CFString=}$kVTCompressionPropertyKey_Depth@^{__CFString=}$kVTCompressionPropertyKey_EncoderID@^{__CFString=}$kVTCompressionPropertyKey_ExpectedDuration@^{__CFString=}$kVTCompressionPropertyKey_ExpectedFrameRate@^{__CFString=}$kVTCompressionPropertyKey_FieldCount@^{__CFString=}$kVTCompressionPropertyKey_FieldDetail@^{__CFString=}$kVTCompressionPropertyKey_GammaLevel@^{__CFString=}$kVTCompressionPropertyKey_H264EntropyMode@^{__CFString=}$kVTCompressionPropertyKey_ICCProfile@^{__CFString=}$kVTCompressionPropertyKey_MasteringDisplayColorVolume@^{__CFString=}$kVTCompressionPropertyKey_MaxFrameDelayCount@^{__CFString=}$kVTCompressionPropertyKey_MaxH264SliceBytes@^{__CFString=}$kVTCompressionPropertyKey_MaxKeyFrameInterval@^{__CFString=}$kVTCompressionPropertyKey_MaxKeyFrameIntervalDuration@^{__CFString=}$kVTCompressionPropertyKey_MaximizePowerEfficiency@^{__CFString=}$kVTCompressionPropertyKey_MoreFramesAfterEnd@^{__CFString=}$kVTCompressionPropertyKey_MoreFramesBeforeStart@^{__CFString=}$kVTCompressionPropertyKey_MultiPassStorage@^{__CFString=}$kVTCompressionPropertyKey_NumberOfPendingFrames@^{__CFString=}$kVTCompressionPropertyKey_PixelAspectRatio@^{__CFString=}$kVTCompressionPropertyKey_PixelBufferPoolIsShared@^{__CFString=}$kVTCompressionPropertyKey_PixelTransferProperties@^{__CFString=}$kVTCompressionPropertyKey_ProfileLevel@^{__CFString=}$kVTCompressionPropertyKey_ProgressiveScan@^{__CFString=}$kVTCompressionPropertyKey_Quality@^{__CFString=}$kVTCompressionPropertyKey_RealTime@^{__CFString=}$kVTCompressionPropertyKey_SourceFrameCount@^{__CFString=}$kVTCompressionPropertyKey_TargetQualityForAlpha@^{__CFString=}$kVTCompressionPropertyKey_TransferFunction@^{__CFString=}$kVTCompressionPropertyKey_UsingGPURegistryID@^{__CFString=}$kVTCompressionPropertyKey_UsingHardwareAcceleratedVideoEncoder@^{__CFString=}$kVTCompressionPropertyKey_VideoEncoderPixelBufferAttributes@^{__CFString=}$kVTCompressionPropertyKey_YCbCrMatrix@^{__CFString=}$kVTDecompressionPropertyKey_ContentHasInterframeDependencies@^{__CFString=}$kVTDecompressionPropertyKey_DeinterlaceMode@^{__CFString=}$kVTDecompressionPropertyKey_FieldMode@^{__CFString=}$kVTDecompressionPropertyKey_MaxOutputPresentationTimeStampOfFramesBeingDecoded@^{__CFString=}$kVTDecompressionPropertyKey_MaximizePowerEfficiency@^{__CFString=}$kVTDecompressionPropertyKey_MinOutputPresentationTimeStampOfFramesBeingDecoded@^{__CFString=}$kVTDecompressionPropertyKey_NumberOfFramesBeingDecoded@^{__CFString=}$kVTDecompressionPropertyKey_OnlyTheseFrames@^{__CFString=}$kVTDecompressionPropertyKey_OutputPoolRequestedMinimumBufferCount@^{__CFString=}$kVTDecompressionPropertyKey_PixelBufferPool@^{__CFString=}$kVTDecompressionPropertyKey_PixelBufferPoolIsShared@^{__CFString=}$kVTDecompressionPropertyKey_PixelFormatsWithReducedResolutionSupport@^{__CFString=}$kVTDecompressionPropertyKey_PixelTransferProperties@^{__CFString=}$kVTDecompressionPropertyKey_RealTime@^{__CFString=}$kVTDecompressionPropertyKey_ReducedCoefficientDecode@^{__CFString=}$kVTDecompressionPropertyKey_ReducedFrameDelivery@^{__CFString=}$kVTDecompressionPropertyKey_ReducedResolutionDecode@^{__CFString=}$kVTDecompressionPropertyKey_SuggestedQualityOfServiceTiers@^{__CFString=}$kVTDecompressionPropertyKey_SupportedPixelFormatsOrderedByPerformance@^{__CFString=}$kVTDecompressionPropertyKey_SupportedPixelFormatsOrderedByQuality@^{__CFString=}$kVTDecompressionPropertyKey_ThreadCount@^{__CFString=}$kVTDecompressionPropertyKey_UsingGPURegistryID@^{__CFString=}$kVTDecompressionPropertyKey_UsingHardwareAcceleratedVideoDecoder@^{__CFString=}$kVTDecompressionProperty_DeinterlaceMode_Temporal@^{__CFString=}$kVTDecompressionProperty_DeinterlaceMode_VerticalFilter@^{__CFString=}$kVTDecompressionProperty_FieldMode_BothFields@^{__CFString=}$kVTDecompressionProperty_FieldMode_BottomFieldOnly@^{__CFString=}$kVTDecompressionProperty_FieldMode_DeinterlaceFields@^{__CFString=}$kVTDecompressionProperty_FieldMode_SingleField@^{__CFString=}$kVTDecompressionProperty_FieldMode_TopFieldOnly@^{__CFString=}$kVTDecompressionProperty_OnlyTheseFrames_AllFrames@^{__CFString=}$kVTDecompressionProperty_OnlyTheseFrames_IFrames@^{__CFString=}$kVTDecompressionProperty_OnlyTheseFrames_KeyFrames@^{__CFString=}$kVTDecompressionProperty_OnlyTheseFrames_NonDroppableFrames@^{__CFString=}$kVTDecompressionProperty_TemporalLevelLimit@^{__CFString=}$kVTDecompressionResolutionKey_Height@^{__CFString=}$kVTDecompressionResolutionKey_Width@^{__CFString=}$kVTDownsamplingMode_Average@^{__CFString=}$kVTDownsamplingMode_Decimate@^{__CFString=}$kVTEncodeFrameOptionKey_ForceKeyFrame@^{__CFString=}$kVTH264EntropyMode_CABAC@^{__CFString=}$kVTH264EntropyMode_CAVLC@^{__CFString=}$kVTMultiPassStorageCreationOption_DoNotDelete@^{__CFString=}$kVTPixelTransferPropertyKey_DestinationCleanAperture@^{__CFString=}$kVTPixelTransferPropertyKey_DestinationColorPrimaries@^{__CFString=}$kVTPixelTransferPropertyKey_DestinationICCProfile@^{__CFString=}$kVTPixelTransferPropertyKey_DestinationPixelAspectRatio@^{__CFString=}$kVTPixelTransferPropertyKey_DestinationTransferFunction@^{__CFString=}$kVTPixelTransferPropertyKey_DestinationYCbCrMatrix@^{__CFString=}$kVTPixelTransferPropertyKey_DownsamplingMode@^{__CFString=}$kVTPixelTransferPropertyKey_RealTime@^{__CFString=}$kVTPixelTransferPropertyKey_ScalingMode@^{__CFString=}$kVTProfileLevel_H263_Profile0_Level10@^{__CFString=}$kVTProfileLevel_H263_Profile0_Level45@^{__CFString=}$kVTProfileLevel_H263_Profile3_Level45@^{__CFString=}$kVTProfileLevel_H264_Baseline_1_3@^{__CFString=}$kVTProfileLevel_H264_Baseline_3_0@^{__CFString=}$kVTProfileLevel_H264_Baseline_3_1@^{__CFString=}$kVTProfileLevel_H264_Baseline_3_2@^{__CFString=}$kVTProfileLevel_H264_Baseline_4_0@^{__CFString=}$kVTProfileLevel_H264_Baseline_4_1@^{__CFString=}$kVTProfileLevel_H264_Baseline_4_2@^{__CFString=}$kVTProfileLevel_H264_Baseline_5_0@^{__CFString=}$kVTProfileLevel_H264_Baseline_5_1@^{__CFString=}$kVTProfileLevel_H264_Baseline_5_2@^{__CFString=}$kVTProfileLevel_H264_Baseline_AutoLevel@^{__CFString=}$kVTProfileLevel_H264_Extended_5_0@^{__CFString=}$kVTProfileLevel_H264_Extended_AutoLevel@^{__CFString=}$kVTProfileLevel_H264_High_3_0@^{__CFString=}$kVTProfileLevel_H264_High_3_1@^{__CFString=}$kVTProfileLevel_H264_High_3_2@^{__CFString=}$kVTProfileLevel_H264_High_4_0@^{__CFString=}$kVTProfileLevel_H264_High_4_1@^{__CFString=}$kVTProfileLevel_H264_High_4_2@^{__CFString=}$kVTProfileLevel_H264_High_5_0@^{__CFString=}$kVTProfileLevel_H264_High_5_1@^{__CFString=}$kVTProfileLevel_H264_High_5_2@^{__CFString=}$kVTProfileLevel_H264_High_AutoLevel@^{__CFString=}$kVTProfileLevel_H264_Main_3_0@^{__CFString=}$kVTProfileLevel_H264_Main_3_1@^{__CFString=}$kVTProfileLevel_H264_Main_3_2@^{__CFString=}$kVTProfileLevel_H264_Main_4_0@^{__CFString=}$kVTProfileLevel_H264_Main_4_1@^{__CFString=}$kVTProfileLevel_H264_Main_4_2@^{__CFString=}$kVTProfileLevel_H264_Main_5_0@^{__CFString=}$kVTProfileLevel_H264_Main_5_1@^{__CFString=}$kVTProfileLevel_H264_Main_5_2@^{__CFString=}$kVTProfileLevel_H264_Main_AutoLevel@^{__CFString=}$kVTProfileLevel_HEVC_Main10_AutoLevel@^{__CFString=}$kVTProfileLevel_HEVC_Main_AutoLevel@^{__CFString=}$kVTProfileLevel_MP4V_AdvancedSimple_L0@^{__CFString=}$kVTProfileLevel_MP4V_AdvancedSimple_L1@^{__CFString=}$kVTProfileLevel_MP4V_AdvancedSimple_L2@^{__CFString=}$kVTProfileLevel_MP4V_AdvancedSimple_L3@^{__CFString=}$kVTProfileLevel_MP4V_AdvancedSimple_L4@^{__CFString=}$kVTProfileLevel_MP4V_Main_L2@^{__CFString=}$kVTProfileLevel_MP4V_Main_L3@^{__CFString=}$kVTProfileLevel_MP4V_Main_L4@^{__CFString=}$kVTProfileLevel_MP4V_Simple_L0@^{__CFString=}$kVTProfileLevel_MP4V_Simple_L1@^{__CFString=}$kVTProfileLevel_MP4V_Simple_L2@^{__CFString=}$kVTProfileLevel_MP4V_Simple_L3@^{__CFString=}$kVTPropertyDocumentationKey@^{__CFString=}$kVTPropertyReadWriteStatusKey@^{__CFString=}$kVTPropertyReadWriteStatus_ReadOnly@^{__CFString=}$kVTPropertyReadWriteStatus_ReadWrite@^{__CFString=}$kVTPropertyShouldBeSerializedKey@^{__CFString=}$kVTPropertySupportedValueListKey@^{__CFString=}$kVTPropertySupportedValueMaximumKey@^{__CFString=}$kVTPropertySupportedValueMinimumKey@^{__CFString=}$kVTPropertyTypeKey@^{__CFString=}$kVTPropertyType_Boolean@^{__CFString=}$kVTPropertyType_Enumeration@^{__CFString=}$kVTPropertyType_Number@^{__CFString=}$kVTScalingMode_CropSourceToCleanAperture@^{__CFString=}$kVTScalingMode_Letterbox@^{__CFString=}$kVTScalingMode_Normal@^{__CFString=}$kVTScalingMode_Trim@^{__CFString=}$kVTVideoDecoderSpecification_EnableHardwareAcceleratedVideoDecoder@^{__CFString=}$kVTVideoDecoderSpecification_PreferredDecoderGPURegistryID@^{__CFString=}$kVTVideoDecoderSpecification_RequireHardwareAcceleratedVideoDecoder@^{__CFString=}$kVTVideoDecoderSpecification_RequiredDecoderGPURegistryID@^{__CFString=}$kVTVideoEncoderList_CodecName@^{__CFString=}$kVTVideoEncoderList_CodecType@^{__CFString=}$kVTVideoEncoderList_DisplayName@^{__CFString=}$kVTVideoEncoderList_EncoderID@^{__CFString=}$kVTVideoEncoderList_EncoderName@^{__CFString=}$kVTVideoEncoderList_GPURegistryID@^{__CFString=}$kVTVideoEncoderList_InstanceLimit@^{__CFString=}$kVTVideoEncoderList_IsHardwareAccelerated@^{__CFString=}$kVTVideoEncoderList_PerformanceRating@^{__CFString=}$kVTVideoEncoderList_QualityRating@^{__CFString=}$kVTVideoEncoderList_SupportedSelectionProperties@^{__CFString=}$kVTVideoEncoderSpecification_EnableHardwareAcceleratedVideoEncoder@^{__CFString=}$kVTVideoEncoderSpecification_EncoderID@^{__CFString=}$kVTVideoEncoderSpecification_PreferredEncoderGPURegistryID@^{__CFString=}$kVTVideoEncoderSpecification_RequireHardwareAcceleratedVideoEncoder@^{__CFString=}$kVTVideoEncoderSpecification_RequiredEncoderGPURegistryID@^{__CFString=}$"""
enums = """$kVTAllocationFailedErr@-12904$kVTColorCorrectionImageRotationFailedErr@-12219$kVTColorCorrectionPixelTransferFailedErr@-12212$kVTColorSyncTransformConvertFailedErr@-12919$kVTCompressionSessionBeginFinalPass@1$kVTCouldNotCreateColorCorrectionDataErr@-12918$kVTCouldNotCreateInstanceErr@-12907$kVTCouldNotFindTemporalFilterErr@-12217$kVTCouldNotFindVideoDecoderErr@-12906$kVTCouldNotFindVideoEncoderErr@-12908$kVTDecodeFrame_1xRealTimePlayback@4$kVTDecodeFrame_DoNotOutputFrame@2$kVTDecodeFrame_EnableAsynchronousDecompression@1$kVTDecodeFrame_EnableTemporalProcessing@8$kVTDecodeInfo_Asynchronous@1$kVTDecodeInfo_FrameDropped@2$kVTDecodeInfo_ImageBufferModifiable@4$kVTEncodeInfo_Asynchronous@1$kVTEncodeInfo_FrameDropped@2$kVTFormatDescriptionChangeNotSupportedErr@-12916$kVTFrameSiloInvalidTimeRangeErr@-12216$kVTFrameSiloInvalidTimeStampErr@-12215$kVTImageRotationNotSupportedErr@-12914$kVTInsufficientSourceColorDataErr@-12917$kVTInvalidSessionErr@-12903$kVTMultiPassStorageIdentifierMismatchErr@-12213$kVTMultiPassStorageInvalidErr@-12214$kVTParameterErr@-12902$kVTPixelTransferNotPermittedErr@-12218$kVTPixelTransferNotSupportedErr@-12905$kVTPropertyNotSupportedErr@-12900$kVTPropertyReadOnlyErr@-12901$kVTSessionMalfunctionErr@-17691$kVTUnlimitedFrameDelayCount@-1$kVTVideoDecoderAuthorizationErr@-12210$kVTVideoDecoderBadDataErr@-12909$kVTVideoDecoderMalfunctionErr@-12911$kVTVideoDecoderNotAvailableNowErr@-12913$kVTVideoDecoderRemovedErr@-17690$kVTVideoDecoderUnsupportedDataFormatErr@-12910$kVTVideoEncoderAuthorizationErr@-12211$kVTVideoEncoderMalfunctionErr@-12912$kVTVideoEncoderNotAvailableNowErr@-12915$"""
misc.update({})
functions = {
    "VTPixelTransferSessionCreate": (
        sel32or64(
            b"l^{__CFAllocator=}^^{OpaqueVTPixelTransferSession=}",
            b"i^{__CFAllocator=}^^{OpaqueVTPixelTransferSession=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTCreateCGImageFromCVPixelBuffer": (
        sel32or64(
            b"l^{__CVBuffer=}^{__CFDictionary=}^^{CGImage=}",
            b"i^{__CVBuffer=}^{__CFDictionary=}^^{CGImage=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTMultiPassStorageGetTypeID": (sel32or64(b"L", b"Q"),),
    "VTDecompressionSessionFinishDelayedFrames": (
        sel32or64(
            b"l^{OpaqueVTDecompressionSession=}", b"i^{OpaqueVTDecompressionSession=}"
        ),
    ),
    "VTSessionCopySupportedPropertyDictionary": (
        sel32or64(b"l@^^{__CFDictionary=}", b"i@^^{__CFDictionary=}"),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTSessionSetProperty": (sel32or64(b"l@^{__CFString=}@", b"i@^{__CFString=}@"),),
    "VTPixelTransferSessionTransferImage": (
        sel32or64(
            b"l^{OpaqueVTPixelTransferSession=}^{__CVBuffer=}^{__CVBuffer=}",
            b"i^{OpaqueVTPixelTransferSession=}^{__CVBuffer=}^{__CVBuffer=}",
        ),
    ),
    "VTFrameSiloGetProgressOfCurrentPass": (
        sel32or64(b"l^{OpaqueVTFrameSilo=}^f", b"i^{OpaqueVTFrameSilo=}^f"),
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "VTMultiPassStorageClose": (
        sel32or64(b"l^{OpaqueVTMultiPassStorage=}", b"i^{OpaqueVTMultiPassStorage=}"),
    ),
    "VTIsHardwareDecodeSupported": (sel32or64(b"ZL", b"ZI"),),
    "VTCompressionSessionPrepareToEncodeFrames": (
        sel32or64(
            b"l^{OpaqueVTCompressionSession=}", b"i^{OpaqueVTCompressionSession=}"
        ),
    ),
    "VTCompressionSessionInvalidate": (b"v^{OpaqueVTCompressionSession=}",),
    "VTCompressionSessionCompleteFrames": (
        sel32or64(
            b"l^{OpaqueVTCompressionSession=}{_CMTime=qiIq}",
            b"i^{OpaqueVTCompressionSession=}{_CMTime=qiIq}",
        ),
    ),
    "VTFrameSiloCallBlockForEachSampleBuffer": (
        sel32or64(
            b"l^{OpaqueVTFrameSilo=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}@?",
            b"i^{OpaqueVTFrameSilo=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}@?",
        ),
        "",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "^{opaqueCMSampleBuffer=}"},
                        },
                    },
                    "block": {
                        "retval": {"type": b"i"},
                        "arguments": {0: {"type": b"^{opaqueCMSampleBuffer=}"}},
                    },
                }
            }
        },
    ),
    "VTSessionCopyProperty": (
        sel32or64(
            b"l@^{__CFString=}^{__CFAllocator=}^@",
            b"i@^{__CFString=}^{__CFAllocator=}^@",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {3: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTFrameSiloAddSampleBuffer": (
        sel32or64(
            b"l^{OpaqueVTFrameSilo=}^{opaqueCMSampleBuffer=}",
            b"i^{OpaqueVTFrameSilo=}^{opaqueCMSampleBuffer=}",
        ),
    ),
    "VTDecompressionSessionDecodeFrame": (
        sel32or64(
            b"l^{OpaqueVTDecompressionSession=}^{opaqueCMSampleBuffer=}I^v^L",
            b"i^{OpaqueVTDecompressionSession=}^{opaqueCMSampleBuffer=}I^v^I",
        ),
        "",
        {"arguments": {4: {"type_modifier": "o"}}},
    ),
    "VTRegisterProfessionalVideoWorkflowVideoEncoders": (b"v",),
    "VTCompressionSessionEncodeFrameWithOutputHandler": (
        sel32or64(
            b"l^{OpaqueVTCompressionSession=}^{__CVBuffer=}{_CMTime=qiIq}{_CMTime=qiIq}^{__CFDictionary=}^L@?",
            b"i^{OpaqueVTCompressionSession=}^{__CVBuffer=}{_CMTime=qiIq}{_CMTime=qiIq}^{__CFDictionary=}^I@?",
        ),
        "",
        {
            "arguments": {
                5: {"type_modifier": "o"},
                6: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "i"},
                            2: {"type": [u"I", u"Q"]},
                            3: {"type": "^{opaqueCMSampleBuffer=}"},
                        },
                    }
                },
            }
        },
    ),
    "VTPixelTransferSessionGetTypeID": (sel32or64(b"L", b"Q"),),
    "VTCompressionSessionGetTypeID": (sel32or64(b"L", b"Q"),),
    "VTCompressionSessionGetPixelBufferPool": (
        b"^{__CVPixelBufferPool=}^{OpaqueVTCompressionSession=}",
    ),
    "VTFrameSiloCallFunctionForEachSampleBuffer": (
        sel32or64(
            b"l^{OpaqueVTFrameSilo=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^v^?",
            b"i^{OpaqueVTFrameSilo=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^v^?",
        ),
        "",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"i"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"^{opaqueCMSampleBuffer=}"},
                        },
                    },
                    "callable_retained": False,
                }
            }
        },
    ),
    "VTDecompressionSessionCopyBlackPixelBuffer": (
        sel32or64(
            b"l^{OpaqueVTDecompressionSession=}^^{__CVBuffer=}",
            b"i^{OpaqueVTDecompressionSession=}^^{__CVBuffer=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTDecompressionSessionCanAcceptFormatDescription": (
        b"Z^{OpaqueVTDecompressionSession=}^{opaqueCMFormatDescription=}",
    ),
    "VTCopyVideoEncoderList": (
        sel32or64(
            b"l^{__CFDictionary=}^^{__CFArray=}", b"i^{__CFDictionary=}^^{__CFArray=}"
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {1: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTMultiPassStorageCreate": (
        sel32or64(
            b"l^{__CFAllocator=}^{__CFURL=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^{__CFDictionary=}^^{OpaqueVTMultiPassStorage=}",
            b"i^{__CFAllocator=}^{__CFURL=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^{__CFDictionary=}^^{OpaqueVTMultiPassStorage=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {4: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTDecompressionSessionGetTypeID": (sel32or64(b"L", b"Q"),),
    "VTCompressionSessionBeginPass": (
        sel32or64(
            b"l^{OpaqueVTCompressionSession=}I^I", b"i^{OpaqueVTCompressionSession=}I^I"
        ),
    ),
    "VTSessionSetProperties": (
        sel32or64(b"l@^{__CFDictionary=}", b"i@^{__CFDictionary=}"),
    ),
    "VTDecompressionSessionWaitForAsynchronousFrames": (
        sel32or64(
            b"l^{OpaqueVTDecompressionSession=}", b"i^{OpaqueVTDecompressionSession=}"
        ),
    ),
    "VTFrameSiloSetTimeRangesForNextPass": (
        sel32or64(
            b"l^{OpaqueVTFrameSilo=}l^{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}",
            b"i^{OpaqueVTFrameSilo=}q^{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}",
        ),
        "",
        {"arguments": {2: {"c_array_length_in_arg": 1, "type_modifier": "n"}}},
    ),
    "VTRegisterProfessionalVideoWorkflowVideoDecoders": (b"v",),
    "VTPixelTransferSessionInvalidate": (b"v^{OpaqueVTPixelTransferSession=}",),
    "VTDecompressionSessionDecodeFrameWithOutputHandler": (
        sel32or64(
            b"l^{OpaqueVTDecompressionSession=}^{opaqueCMSampleBuffer=}I^L@?",
            b"i^{OpaqueVTDecompressionSession=}^{opaqueCMSampleBuffer=}I^I@?",
        ),
        "",
        {
            "arguments": {
                3: {"type_modifier": "o"},
                4: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": "^v"},
                            1: {"type": "i"},
                            2: {"type": "I"},
                            3: {"type": "^{__CVBuffer=}"},
                            4: {"type": "{_CMTime=qiIq}"},
                            5: {"type": "{_CMTime=qiIq}"},
                        },
                    }
                },
            }
        },
    ),
    "VTCompressionSessionEndPass": (
        sel32or64(
            b"l^{OpaqueVTCompressionSession=}^Z^I",
            b"i^{OpaqueVTCompressionSession=}^Z^I",
        ),
        "",
        {"arguments": {1: {"type_modifier": "o"}}},
    ),
    "VTCompressionSessionEncodeFrame": (
        sel32or64(
            b"l^{OpaqueVTCompressionSession=}^{__CVBuffer=}{_CMTime=qiIq}{_CMTime=qiIq}^{__CFDictionary=}^v^L",
            b"i^{OpaqueVTCompressionSession=}^{__CVBuffer=}{_CMTime=qiIq}{_CMTime=qiIq}^{__CFDictionary=}^v^I",
        ),
        "",
        {"arguments": {6: {"type_modifier": "o"}}},
    ),
    "VTFrameSiloCreate": (
        sel32or64(
            b"l^{__CFAllocator=}^{__CFURL=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^{__CFDictionary=}^^{OpaqueVTFrameSilo=}",
            b"i^{__CFAllocator=}^{__CFURL=}{_CMTimeRange={_CMTime=qiIq}{_CMTime=qiIq}}^{__CFDictionary=}^^{OpaqueVTFrameSilo=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {4: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTCompressionSessionCreate": (
        sel32or64(
            b"l^{__CFAllocator=}iiL^{__CFDictionary=}^{__CFDictionary=}^{__CFAllocator=}^?^v^^{OpaqueVTCompressionSession=}",
            b"i^{__CFAllocator=}iiI^{__CFDictionary=}^{__CFDictionary=}^{__CFAllocator=}^?^v^^{OpaqueVTCompressionSession=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                9: {"already_cfretained": True, "type_modifier": "o"},
                7: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"^v"},
                            2: {"type": b"i"},
                            3: {"type": b"I"},
                            4: {"type": b"^{opaqueCMSampleBuffer=}"},
                        },
                    }
                },
            },
        },
    ),
    "VTCopySupportedPropertyDictionaryForEncoder": (
        sel32or64(
            b"liiL^{__CFDictionary=}^^{__CFString=}^^{__CFDictionary=}",
            b"iiiI^{__CFDictionary=}^^{__CFString=}^^{__CFDictionary=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {
                4: {"already_cfretained": True, "type_modifier": "o"},
                5: {"already_cfretained": True, "type_modifier": "o"},
            },
        },
    ),
    "VTFrameSiloGetTypeID": (sel32or64(b"L", b"Q"),),
    "VTSessionCopySerializableProperties": (
        sel32or64(
            b"l@^{__CFAllocator=}^^{__CFDictionary=}",
            b"i@^{__CFAllocator=}^^{__CFDictionary=}",
        ),
        "",
        {
            "retval": {"already_cfretained": True},
            "arguments": {2: {"already_cfretained": True, "type_modifier": "o"}},
        },
    ),
    "VTDecompressionSessionInvalidate": (b"v^{OpaqueVTDecompressionSession=}",),
}
aliases = {"VT_SUPPORT_COLORSYNC_PIXEL_TRANSFER": "COREMEDIA_TRUE"}
cftypes = [
    (
        "VTPixelTransferSessionRef",
        b"^{OpaqueVTPixelTransferSession=}",
        ":VTPixelTransferSessionGetTypeID",
        None,
    ),
    (
        "VTDecompressionSessionRef",
        b"^{OpaqueVTDecompressionSession=}",
        ":VTDecompressionSessionGetTypeID",
        None,
    ),
    ("VTFrameSiloRef", b"^{OpaqueVTFrameSilo=}", ":VTFrameSiloGetTypeID", None),
    ("VTSessionRef", b"^{OpaqueVTSession=}", ":VTSessionGetTypeID", None),
    (
        "VTMultiPassStorageRef",
        b"^{OpaqueVTMultiPassStorage=}",
        ":VTMultiPassStorageGetTypeID",
        None,
    ),
]
expressions = {}

# END OF FILE
